import QtQuick 1.1
import QtMobility.sensors 1.2
import QtMultimediaKit 1.1
import QtMobility.feedback 1.1
import "Utils.js" as Utils
import com.nokia.meego 1.0
//import "inneractive"

PageStackWindow {
    id: window
    showStatusBar: false
    showToolBar: false
    initialPage: Page {
        orientationLock: PageOrientation.LockPortrait
        anchors.fill: parent
        //visible: true
        Image {
        property int internalWidth: width*0.9
        property int internalStartX: x+ width*0.05
        property int internalCenterY: (y + height/2+likeBtn.height+playBtn.height/2);
        property string version: "1.0";
        property string game_name: "Dice";
        property string company_name: "Future soft";

        property bool soundState: true
        property bool popupShowed: false

        function showHelp()
        {
            dialog.setTextHeader("Help");
            dialog.showHelp();
            //dialog.setPadding(5);
            //dialog.setPaintableArea(helpDlg);
            //drawer.addPaintable(dialog);
            popupShowed = true;
        }

        function showAbout()
        {
            dialog.setTextHeader("");
            dialog.showAbout();
            //dialog.setPadding(5);
            //dialog.setPaintableArea(helpDlg);
            //drawer.addPaintable(dialog);
            popupShowed = true;
        }

        function showGame()
        {
            //menu.visible = false;
            gameScreen.visible = true;
            gameScreen.show();
        }

        function showMenu()
        {
            gameScreen.visible = false;
            //menu.visible = true
        }

        Component.onCompleted: {
            Math.random(new Date().getTime());
        }
        //Image {
            id: menu
            anchors.fill: parent
            source: "images/bg.png"
            fillMode: Image.Stretch
        //}
        Image {
            id: soundBtn
            anchors.top: parent.top
            anchors.left: parent.left
            source: menu.soundState?"images/sound_normal.png":"images/sound_pressed.png";
            MouseArea {
                anchors.fill: parent
                onClicked: menu.soundState = !menu.soundState;
            }
        }

        Image {
            id: exitBtn
            anchors.top: parent.top
            anchors.right: parent.right
            source: "images/exit_normal.png"
            MouseArea {
                enabled: gameScreen.visible == false;
                anchors.fill: parent
                onPressed: parent.source = "images/exit_pressed.png";
                onReleased: parent.source = "images/exit_normal.png"
                onClicked: Qt.quit();
            }
        }

        Image {
            id: aboutBtn
            anchors.verticalCenter: playBtn.verticalCenter
            anchors.left: parent.left
            anchors.leftMargin: 0.05*parent.width
            source: "images/info_normal.png"
            MouseArea {
                enabled: gameScreen.visible == false;
                anchors.fill: parent
                onPressed: parent.source = "images/info_pressed.png";
                onReleased: parent.source = "images/info_normal.png"
                onClicked: menu.showAbout();
            }
        }
        Image {
            id: playBtn
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.top: likeBtn.bottom
            anchors.topMargin: 10
            source: "images/play_normal.png"
            MouseArea {
                enabled: gameScreen.visible == false;
                anchors.fill: parent
                onPressed: parent.source = "images/play_pressed.png";
                onReleased: parent.source = "images/play_normal.png"
                onClicked: menu.showGame();
            }
        }
        Image {
            id: helpBtn
            anchors.verticalCenter: playBtn.verticalCenter
            anchors.right: parent.right
            anchors.rightMargin: 0.05*parent.width
            source: "images/help_normal.png"
            MouseArea {
                enabled: gameScreen.visible == false;
                anchors.fill: parent
                onPressed: parent.source = "images/help_pressed.png";
                onReleased: parent.source = "images/help_normal.png"
                onClicked: menu.showHelp();
            }
        }

        Image {
            id: likeBtn
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.verticalCenter: parent.verticalCenter
            anchors.verticalCenterOffset: 15
            source: "images/like.png"
            MouseArea {
                enabled: gameScreen.visible == false;
                anchors.fill: parent
                onClicked: Qt.openUrlExternally("http://touch.facebook.com/pages/Future-soft/207935900738")
            }
        }
        Image {
            id: bannerTemplate
            source: "images/banner.png"
            anchors.bottom: adMenu.top
            anchors.bottomMargin: 20
            anchors.horizontalCenter: parent.horizontalCenter
            MouseArea {
                enabled: gameScreen.visible == false;
                anchors.fill: parent
                onClicked: Qt.openUrlExternally("http://store.ovi.mobi/publisher/Future+soft")
            }
        }
        AdItem {
            id: adMenu
            parameters: AdParameters {

                applicationId: "FutureSoft_Dice_Nokia"
            }
            onAdLoaded: { console.log(adClickUrl + " " + adImageUrl); }
            visible: gameScreen.visible == false
            anchors.bottom: parent.bottom
            anchors.horizontalCenter: parent.horizontalCenter
            scaleAd: true
            width: parent.width
            height: bannerTemplate.height+10
            showText: false
            retryOnError: true
            reloadInterval: 45
        }

        Image {
            id: logoImg
            anchors.bottom: likeBtn.top
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.bottomMargin: 5
            source: "images/logo.png"
        }

        BorderImage {
            function setTextHeader(text)
            {
                header.text = text;
            }

            function showHelp()
            {
                aboutComp.visible = false;
                helpText.visible = true;
            }

            function showAbout()
            {
                helpText.visible = false;
                aboutComp.visible = true;
            }

            id: dialog
            anchors.left: parent.left
            anchors.leftMargin: parent.width*0.1
            anchors.verticalCenter: parent.verticalCenter
            width: parent.width*0.8
            height: parent.height*0.4
            visible: menu.popupShowed
            horizontalTileMode: BorderImage.Repeat
            verticalTileMode: BorderImage.Repeat
            source: "images/popupbg.png"
            border.top: 20
            border.bottom: 20
            border.left: 20
            border.right: 20
            Text {
                id: header
                text: qsTr("")
                anchors.top: parent.top
                anchors.topMargin: 5
                anchors.horizontalCenter: parent.horizontalCenter
                font { family: "Arial"; pixelSize: 36; bold: true }
                color: "black"
            }

            Item {
                visible: false
                id: helpText
                anchors.left: parent.left
                anchors.leftMargin: 10
                anchors.right: parent.right
                anchors.rightMargin: 10
                anchors.top: header.bottom
                anchors.topMargin: 10
                anchors.bottom: parent.bottom
                anchors.bottomMargin: 10
                Text {
                    id: name
                    anchors.fill: parent
                    wrapMode: Text.WordWrap
                    font { family: "Arial"; pixelSize: 26; bold: false }
                    text: qsTr("Press the play button to show the Dice screen.\nShake the phone to roll the dice.\nPress the sound button to toggle the sound & vibration.")
                    color: "black"
                }
            }

            Item {
                visible: false
                id: aboutComp
                anchors.left: parent.left
                anchors.leftMargin: 10
                anchors.right: parent.right
                anchors.rightMargin: 10
                anchors.top: parent.top
                anchors.topMargin: 10
                anchors.bottom: parent.bottom
                anchors.bottomMargin: 10
                Image {
                    id: companyIcon
                    source: "images/company_icon.png"
                    anchors.right: parent.right
                    anchors.top: parent.top
                    anchors.rightMargin: 10
                }
                Image {
                    id: appIcon
                    source: "images/icon.png"
                    anchors.left: parent.left
                    anchors.verticalCenter: companyIcon.verticalCenter
                }

                Text {
                    id: appNameLabel
                    anchors.left: parent.left
                    anchors.top: appIcon.bottom
                    anchors.topMargin: 5
                    wrapMode: Text.WordWrap
                    font { family: "Arial"; pixelSize: 32; bold: true }
                    text: qsTr(menu.game_name)
                    color: "black"
                }
                Text {
                    id: versionLabel
                    anchors.left: parent.left
                    anchors.top: appNameLabel.bottom
                    anchors.topMargin: 5
                    wrapMode: Text.WordWrap
                    font { family: "Arial"; pixelSize: 26; bold: false }
                    text: qsTr("Version " +menu.version)
                    color: "black"
                }
                Text {
                    anchors.left: parent.left
                    anchors.top: versionLabel.bottom
                    anchors.topMargin: 5
                    wrapMode: Text.WordWrap
                    font { family: "Arial"; pixelSize: 26; bold: false }
                    text: qsTr("© 2012 "+menu.company_name)
                    color: "black"
                }
            }
        }
        MouseArea {
            anchors.fill: parent
            enabled: menu.popupShowed
            onClicked: {
                if (menu.popupShowed) {
                    menu.popupShowed = false;
                    mouse.accepted = true;

                }
                else
                {
                    mouse.accepted = false;
                }
            }
        }
        }
        Rectangle
        {
            property bool backVisible: false

            function show()
            {
                dice1.x = Math.random()*parent.width/2+parent.width/4;
                dice1.y = bannerTemplate1.height+ (Math.random()*(parent.height-bannerTemplate1.height)/4+(parent.height-bannerTemplate1.height)/8+(parent.height-bannerTemplate1.height)/2*0);
                dice2.x = Math.random()*parent.width/2+parent.width/4;
                dice2.y = bannerTemplate1.height+ (Math.random()*(parent.height-bannerTemplate1.height)/4+(parent.height-bannerTemplate1.height)/8+(parent.height-bannerTemplate1.height)/2*1);
                dice1.randNumber();
                dice2.randNumber();
                accelerometer.activate();
            }

            function startRolling()
            {
                if (dice1.currentMode == dice1.mode_rolling)
                    return;
                dice1.roll();
                dice2.roll();
                if (cancelRollingTask.running)
                    cancelRollingTask.stop();
                cancelRollingTask.start();
                if (moveDice.running)
                    moveDice.stop();
                moveDice.start();
                if (menu.soundState)
                {
                    rollSound.play();
                    vibrate.start();
                }
            }
            function moveDiceFunc()
            {
                var diceArray = new Array(dice1, dice2);
                if (Utils.rectColide(diceArray[0].getX(), diceArray[0].getY(), diceArray[0].getRollingFrameWidth(), diceArray[0].getRollingFrameHeight(), diceArray[1].getX(), diceArray[1].getY(), diceArray[1].getRollingFrameWidth(), diceArray[1].getRollingFrameHeight()))
                {
                    var temp = 1.0*Math.abs(diceArray[0].getX()-diceArray[1].getX())/Math.abs(diceArray[0].getY()-diceArray[1].getY());
                    console.log(temp);
                    if (temp<0.5)
                    {
                        diceArray[0].setDeltaY(-diceArray[0].getDeltaY());
                        diceArray[1].setDeltaY(-diceArray[1].getDeltaY());
                    }
                    else if (temp>4)
                    {
                        diceArray[0].setDeltaX(-diceArray[0].getDeltaX());
                        diceArray[1].setDeltaX(-diceArray[1].getDeltaX());
                    }
                    else
                    {
                        diceArray[0].setDeltaX(-diceArray[0].getDeltaX());
                        diceArray[1].setDeltaX(-diceArray[1].getDeltaX());
                        diceArray[0].setDeltaY(-diceArray[0].getDeltaY());
                        diceArray[1].setDeltaY(-diceArray[1].getDeltaY());
                    }
                    diceArray[0].move();
                    diceArray[1].move();
                    return;
                }
                diceArray[0].move();
                diceArray[1].move();
                for (var i = 0; i < diceArray.length; i++)
                {
                    if (diceArray[i].getX()-diceArray[i].getRollingFrameWidth()/2<0)
                    {
                        diceArray[i].setX(diceArray[i].getRollingFrameWidth()/2);
                        diceArray[i].setDeltaX(-diceArray[i].getDeltaX());
                    }
                    if (diceArray[i].getX()+diceArray[i].getRollingFrameWidth()/2>gameScreen.width)
                    {
                        diceArray[i].setX(gameScreen.width-diceArray[i].getRollingFrameWidth()/2);
                        diceArray[i].setDeltaX(-diceArray[i].getDeltaX());
                    }
                    if (diceArray[i].getY()-diceArray[i].getRollingFrameHeight()/2<bannerTemplate1.height)
                    {
                        diceArray[i].setY(bannerTemplate1.height+diceArray[i].getRollingFrameHeight()/2);
                        diceArray[i].setDeltaY(-diceArray[i].getDeltaY());
                    }
                    if (diceArray[i].getY()+diceArray[i].getRollingFrameHeight()/2>gameScreen.height)
                    {
                        diceArray[i].setY(gameScreen.height-diceArray[i].getRollingFrameHeight()/2);
                        diceArray[i].setDeltaY(-diceArray[i].getDeltaY());
                    }
                }
            }


            id: gameScreen
            visible: false
            anchors.fill: parent
            color: "#cccccc"
            Timer {
                id: cancelRollingTask
                interval: 2000; running: false; repeat: false
                onTriggered: {
                    dice1.currentMode = dice1.mode_normal;
                    dice2.currentMode = dice2.mode_normal;
                }
            }

            Timer {
                id: moveDice
                interval: 30; running: false; repeat: true
                onTriggered: gameScreen.moveDiceFunc();
            }
            Accelerometer{
                property double direction_delta: 5;
                property variant acceleration: [ 0.0, 0.0, 0.0];
                property bool receivedFirstData: false;
                function activate()
                {
                    receivedFirstData = false;
                    accelerometer.active = true;
                }

                function deactivate()
                {
                    accelerometer.active = false;
                }

                id:accelerometer
                active:false
                onReadingChanged:{
                    if (!receivedFirstData)
                    {
                        receivedFirstData = true;
                        acceleration = new Array(reading.x,reading.y,reading.z);
                        return;
                    }
                    else
                    {
                        var tempArr = new Array(reading.x,reading.y,reading.z);
                        //console.log(Utils.vectorMagnitude(tempArr) + " " + Utils.vectorMagnitude(acceleration));
                        //console.log(acceleration[0] + " " + acceleration[1] + " " + acceleration[2]);
                        var tempArr2 = new Array(tempArr[0]-acceleration[0],tempArr[1]-acceleration[1],tempArr[2]-acceleration[2]);
                        //if (Math.abs(Utils.vectorMagnitude(tempArr)-Utils.vectorMagnitude(acceleration))>direction_delta)
                        if (Utils.vectorMagnitude(tempArr2) > direction_delta)
                        {
                            acceleration = tempArr;
                            //acceleration[0] = tempArr[0];
                            //acceleration[1] = tempArr[1];
                            //acceleration[2] = tempArr[2];
                            //console.log(acceleration[0] + " " + acceleration[1] + " " + acceleration[2]);
                            //console.log("SHAKE!!!");
                            gameScreen.startRolling();
                            //listener.shakeStarted();
                            return;
                        }
                        else
                        {
                            acceleration = tempArr;
                            return;
                        }
                    }
                    //console.log("X= "+reading.x+" Y= "+reading.y+" Z= "+reading.z);
                }
            }
            Image {
                source: "images/shake.png"
                anchors.top: bannerTemplate1.bottom
                anchors.topMargin: 5
                anchors.horizontalCenter: parent.horizontalCenter
            }

            Image {
                id: backBtn
                //visible: false
                source: "images/back.png"
                anchors.bottom: parent.bottom
                anchors.right: parent.right
                MouseArea {
                    anchors.fill: parent
                    enabled: parent.visible
                    onClicked:
                    {
                        accelerometer.deactivate();
                        menu.showMenu();
                    }
                }
            }
            Dice {
                id: dice1
                normalStrip: "images/dice_green.png"
                rollingStrip: "images/dice_green_rolling.png"
                x: Math.random()*parent.width/2+parent.width/4
                y: bannerTemplate1.height+ (Math.random()*(parent.height-bannerTemplate1.height)/4+(parent.height-bannerTemplate1.height)/4+(parent.height-bannerTemplate1.height)/2*0);
            }
            Dice {
                id: dice2
                normalStrip: "images/dice_red.png"
                rollingStrip: "images/dice_red_rolling.png"
                x: Math.random()*parent.width/2+parent.width/4
                y: bannerTemplate1.height+ (Math.random()*(parent.height-bannerTemplate1.height)/4+(parent.height-bannerTemplate1.height)/4+(parent.height-bannerTemplate1.height)/2*1);
            }
            Image {
                visible: false
                id: bannerTemplate1
                source: "images/banner.png"
                anchors.top: parent.top
                anchors.horizontalCenter: parent.horizontalCenter
            }
            AdItem {
                //visible: gameScreen.visible == true
                parameters: AdParameters {

                    applicationId: "FutureSoft_Dice_Nokia"
                }
                //onAdLoaded: {console.log("ADLOADED!")}
                //onAdError: {console.log("ADERROR!")}
                anchors.top: parent.top
                anchors.horizontalCenter: parent.horizontalCenter
                scaleAd: true
                width: parent.width
                height: bannerTemplate1.height
                showText: false
                retryOnError: true
                reloadInterval: 45
            }
            SoundEffect {
                volume: 1.0
                id: rollSound
                source: "roll.wav"
            }

            HapticsEffect {
                id: vibrate
                attackIntensity: 0.0
                attackTime: 50
                intensity: 1.0
                duration: 150 // set up the duration here, in millisecond
                fadeTime: 50
                fadeIntensity: 0.0
            }
        }
    }
}
